@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::copy_rel;
 
-our $DATE = '2016-01-06'; # DATE
-our $VERSION = '0.63'; # VERSION
+our $DATE = '2016-01-16'; # DATE
+our $VERSION = '0.64'; # VERSION
 
 use 5.010;
 use strict;
@@ -19,18 +19,17 @@ $SPEC{'handle_cmd'} = {
         %App::lcpan::rel_args,
         %App::lcpan::overwrite_arg,
     },
+    tags => ['write-to-fs'],
 };
 sub handle_cmd {
     require File::Copy;
 
     my %args = @_;
 
-    App::lcpan::_set_args_default(\%args);
-    my $cpan = $args{cpan};
-    my $index_name = $args{index_name};
-    my $rel = $args{release};
+    my $state = App::lcpan::_init(\%args, 'ro');
+    my $dbh = $state->{dbh};
 
-    my $dbh = App::lcpan::_connect_db('ro', $cpan, $index_name);
+    my $rel = $args{release};
 
     my $row = $dbh->selectrow_hashref("SELECT
   cpanid,
@@ -41,7 +40,8 @@ WHERE name=?
 
     return [404, "No such release"] unless $row;
 
-    my $srcpath = App::lcpan::_relpath($row->{name}, $cpan, $row->{cpanid});
+    my $srcpath = App::lcpan::_relpath(
+        $row->{name}, $state->{cpan}, $row->{cpanid});
     my $targetpath = $row->{name};
 
     if ((-f $targetpath) && !$args{overwrite}) {
@@ -72,7 +72,7 @@ App::lcpan::Cmd::copy_rel - Copy a release file to current directory
 
 =head1 VERSION
 
-This document describes version 0.63 of App::lcpan::Cmd::copy_rel (from Perl distribution App-lcpan), released on 2016-01-06.
+This document describes version 0.64 of App::lcpan::Cmd::copy_rel (from Perl distribution App-lcpan), released on 2016-01-16.
 
 =head1 FUNCTIONS
 
