@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::dist2rel;
 
-our $DATE = '2016-01-06'; # DATE
-our $VERSION = '0.63'; # VERSION
+our $DATE = '2016-01-16'; # DATE
+our $VERSION = '0.64'; # VERSION
 
 use 5.010;
 use strict;
@@ -24,12 +24,10 @@ $SPEC{'handle_cmd'} = {
 sub handle_cmd {
     my %args = @_;
 
-    App::lcpan::_set_args_default(\%args);
-    my $cpan = $args{cpan};
-    my $index_name = $args{index_name};
-    my $dist = $args{dist};
+    my $state = App::lcpan::_init(\%args, 'ro');
+    my $dbh = $state->{dbh};
 
-    my $dbh = App::lcpan::_connect_db('ro', $cpan, $index_name);
+    my $dist = $args{dist};
 
     my $row = $dbh->selectrow_hashref("SELECT
   file.cpanid cpanid,
@@ -42,7 +40,8 @@ ORDER BY version_numified DESC", {}, $dist);
 
     if ($row) {
         if ($args{full_path}) {
-            $rel = App::lcpan::_relpath($row->{name}, $cpan, $row->{cpanid});
+            $rel = App::lcpan::_relpath(
+                $row->{name}, $state->{cpan}, $row->{cpanid});
         } else {
             $rel = $row->{name};
         }
@@ -65,7 +64,7 @@ App::lcpan::Cmd::dist2rel - Get (latest) release name of a distribution
 
 =head1 VERSION
 
-This document describes version 0.63 of App::lcpan::Cmd::dist2rel (from Perl distribution App-lcpan), released on 2016-01-06.
+This document describes version 0.64 of App::lcpan::Cmd::dist2rel (from Perl distribution App-lcpan), released on 2016-01-16.
 
 =head1 FUNCTIONS
 
