@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::distmods;
 
-our $DATE = '2016-01-06'; # DATE
-our $VERSION = '0.63'; # VERSION
+our $DATE = '2016-01-16'; # DATE
+our $VERSION = '0.64'; # VERSION
 
 use 5.010;
 use strict;
@@ -25,14 +25,12 @@ $SPEC{'handle_cmd'} = {
 sub handle_cmd {
     my %args = @_;
 
-    App::lcpan::_set_args_default(\%args);
-    my $cpan = $args{cpan};
-    my $index_name = $args{index_name};
+    my $state = App::lcpan::_init(\%args, 'ro');
+    my $dbh = $state->{dbh};
+
     my $dist = $args{dist};
     my $detail = $args{detail};
 
-    my $dbh = App::lcpan::_connect_db('ro', $cpan, $index_name);
-
     my $sth = $dbh->prepare("SELECT
   module.name name,
   module.version version
@@ -67,7 +65,7 @@ App::lcpan::Cmd::distmods - List modules in a distribution
 
 =head1 VERSION
 
-This document describes version 0.63 of App::lcpan::Cmd::distmods (from Perl distribution App-lcpan), released on 2016-01-06.
+This document describes version 0.64 of App::lcpan::Cmd::distmods (from Perl distribution App-lcpan), released on 2016-01-16.
 
 =head1 FUNCTIONS
 
