@@ -1,12 +1,14 @@
 package App::lcpan::Cmd::dists_by_dep_count;
 
-our $DATE = '2016-01-06'; # DATE
-our $VERSION = '0.63'; # VERSION
+our $DATE = '2016-01-16'; # DATE
+our $VERSION = '0.64'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
 
+use Function::Fallback::CoreOrPP qw(clone_list);
+
 require App::lcpan;
 
 our %SPEC;
@@ -17,8 +19,8 @@ $SPEC{'handle_cmd'} = {
     args => {
         %App::lcpan::common_args,
         %App::lcpan::fauthor_args,
-        %App::lcpan::deps_phase_arg,
-        %App::lcpan::deps_rel_arg,
+        clone_list(%App::lcpan::deps_phase_arg),
+        clone_list(%App::lcpan::deps_rel_arg),
     },
 };
 delete $SPEC{'handle_cmd'}{args}{phase}{default};
@@ -26,11 +28,8 @@ delete $SPEC{'handle_cmd'}{args}{rel}{default};
 sub handle_cmd {
     my %args = @_;
 
-    App::lcpan::_set_args_default(\%args);
-    my $cpan = $args{cpan};
-    my $index_name = $args{index_name};
-
-    my $dbh = App::lcpan::_connect_db('ro', $cpan, $index_name);
+    my $state = App::lcpan::_init(\%args, 'ro');
+    my $dbh = $state->{dbh};
 
     my @where;
     my @binds;
@@ -86,7 +85,7 @@ App::lcpan::Cmd::dists_by_dep_count - List "heavy" distributions (ranked by numb
 
 =head1 VERSION
 
-This document describes version 0.63 of App::lcpan::Cmd::dists_by_dep_count (from Perl distribution App-lcpan), released on 2016-01-06.
+This document describes version 0.64 of App::lcpan::Cmd::dists_by_dep_count (from Perl distribution App-lcpan), released on 2016-01-16.
 
 =head1 FUNCTIONS
 
