@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::extract_rel;
 
-our $DATE = '2016-01-06'; # DATE
-our $VERSION = '0.63'; # VERSION
+our $DATE = '2016-01-16'; # DATE
+our $VERSION = '0.64'; # VERSION
 
 use 5.010;
 use strict;
@@ -18,18 +18,17 @@ $SPEC{'handle_cmd'} = {
         %App::lcpan::common_args,
         %App::lcpan::rel_args,
     },
+    tags => ['write-to-fs'],
 };
 sub handle_cmd {
     require Archive::Extract;
 
     my %args = @_;
 
-    App::lcpan::_set_args_default(\%args);
-    my $cpan = $args{cpan};
-    my $index_name = $args{index_name};
-    my $rel = $args{release};
+    my $state = App::lcpan::_init(\%args, 'ro');
+    my $dbh = $state->{dbh};
 
-    my $dbh = App::lcpan::_connect_db('ro', $cpan, $index_name);
+    my $rel = $args{release};
 
     my $row = $dbh->selectrow_hashref("SELECT
   cpanid,
@@ -40,7 +39,8 @@ WHERE name=?
 
     return [404, "No such release"] unless $row;
 
-    my $path = App::lcpan::_relpath($row->{name}, $cpan, $row->{cpanid});
+    my $path = App::lcpan::_relpath(
+        $row->{name}, $state->{cpan}, $row->{cpanid});
 
     my $ae = Archive::Extract->new(archive => $path);
     $ae->extract or return [500, "Can't extract: " . $ae->error];
@@ -63,7 +63,7 @@ App::lcpan::Cmd::extract_rel - Extract a release to current directory
 
 =head1 VERSION
 
-This document describes version 0.63 of App::lcpan::Cmd::extract_rel (from Perl distribution App-lcpan), released on 2016-01-06.
+This document describes version 0.64 of App::lcpan::Cmd::extract_rel (from Perl distribution App-lcpan), released on 2016-01-16.
 
 =head1 FUNCTIONS
 
