@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::mod2dist;
 
-our $DATE = '2016-01-06'; # DATE
-our $VERSION = '0.63'; # VERSION
+our $DATE = '2016-01-16'; # DATE
+our $VERSION = '0.64'; # VERSION
 
 use 5.010;
 use strict;
@@ -22,12 +22,10 @@ $SPEC{'handle_cmd'} = {
 sub handle_cmd {
     my %args = @_;
 
-    App::lcpan::_set_args_default(\%args);
-    my $cpan = $args{cpan};
-    my $index_name = $args{index_name};
-    my $mods = $args{modules};
+    my $state = App::lcpan::_init(\%args, 'ro');
+    my $dbh = $state->{dbh};
 
-    my $dbh = App::lcpan::_connect_db('ro', $cpan, $index_name);
+    my $mods = $args{modules};
 
     my $mods_s = join(",", map {$dbh->quote($_)} @$mods);
 
@@ -43,7 +41,7 @@ WHERE module.name IN ($mods_s)");
     my $res;
     if (@$mods == 1) {
         $sth->execute;
-        ($res) = $sth->fetchrow_array;
+        (undef, $res) = $sth->fetchrow_array;
     } else {
         $sth->execute;
         $res = {};
@@ -69,7 +67,7 @@ App::lcpan::Cmd::mod2dist - Get distribution name of a module
 
 =head1 VERSION
 
-This document describes version 0.63 of App::lcpan::Cmd::mod2dist (from Perl distribution App-lcpan), released on 2016-01-06.
+This document describes version 0.64 of App::lcpan::Cmd::mod2dist (from Perl distribution App-lcpan), released on 2016-01-16.
 
 =head1 FUNCTIONS
 
